# -*- coding: utf-8 -*-
"""
    flask_oauthlib
    ~~~~~~~~~~~~~~

    Flask-OAuthlib is an extension for Flask that allows you to interact with
    remote OAuth enabled applications, and also helps you creating your own
    OAuth servers.

    :copyright: (c) 2013 by Hsiaoming Yang.
    :license: BSD, see LICENSE for more details.
"""

__version__ = "0.3.2"
__author__ = "Hsiaoming Yang <me@lepture.com>"
__homepage__ = 'https://github.com/lepture/flask-oauthlib'
